@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2020 David Edmundson <davidedmundson@kde.org>
-    Copyright (c) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2020 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "process_attribute_model.h"
@@ -31,7 +18,7 @@ public:
     QVector<ProcessAttribute *> m_attributes;
 };
 
-ProcessAttributeModel::ProcessAttributeModel(const QVector<ProcessAttribute *> & attributes, QObject *parent)
+ProcessAttributeModel::ProcessAttributeModel(const QVector<ProcessAttribute *> &attributes, QObject *parent)
     : QAbstractListModel(parent)
     , d(new Private)
 {
@@ -82,12 +69,12 @@ QVariant ProcessAttributeModel::data(const QModelIndex &index, int role) const
 QHash<int, QByteArray> ProcessAttributeModel::roleNames() const
 {
     return QAbstractListModel::roleNames().unite({
-        { static_cast<int>(Role::Id), "id" },
-        { static_cast<int>(Role::Name), "name" },
-        { static_cast<int>(Role::ShortName), "shortName" },
-        { static_cast<int>(Role::Description), "description" },
-        { static_cast<int>(Role::Unit), "unit" },
-        { static_cast<int>(Role::Minimum), "minimum" },
-        { static_cast<int>(Role::Maximum), "maximum" },
+        {static_cast<int>(Role::Id), "id"},
+        {static_cast<int>(Role::Name), "name"},
+        {static_cast<int>(Role::ShortName), "shortName"},
+        {static_cast<int>(Role::Description), "description"},
+        {static_cast<int>(Role::Unit), "unit"},
+        {static_cast<int>(Role::Minimum), "minimum"},
+        {static_cast<int>(Role::Maximum), "maximum"},
     });
 }
