@@ -1,39 +1,23 @@
 /*
- * This file is part of KSysGuard.
- * Copyright 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
- * 
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "process_controller.h"
 
 #include <functional>
 
-#include <KLocalizedString>
 #include <KAuth/KAuthAction>
 #include <KAuth/KAuthExecuteJob>
+#include <KLocalizedString>
 
-#include "processes_local_p.h"
 #include "processcore_debug.h"
+#include "processes_local_p.h"
 
 using namespace KSysGuard;
 
-struct ApplyResult
-{
+struct ApplyResult {
     ProcessController::Result resultCode = ProcessController::Result::Success;
     QVector<int> unchanged;
 };
@@ -54,8 +38,9 @@ public:
 // used to access information about processes.
 Q_GLOBAL_STATIC(ProcessesLocal, s_localProcesses);
 
-ProcessController::ProcessController(QObject* parent)
-    : QObject(parent), d(new Private)
+ProcessController::ProcessController(QObject *parent)
+    : QObject(parent)
+    , d(new Private)
 {
 }
 
@@ -64,33 +49,31 @@ KSysGuard::ProcessController::~ProcessController()
     // Empty destructor needed for std::unique_ptr to incomplete class.
 }
 
-QWidget * KSysGuard::ProcessController::widget() const
+QWidget *KSysGuard::ProcessController::widget() const
 {
     return d->widget;
 }
 
-void KSysGuard::ProcessController::setWidget(QWidget* widget)
+void KSysGuard::ProcessController::setWidget(QWidget *widget)
 {
     d->widget = widget;
 }
 
-ProcessController::Result ProcessController::sendSignal(const QVector<int>& pids, int signal)
+ProcessController::Result ProcessController::sendSignal(const QVector<int> &pids, int signal)
 {
     qCDebug(LIBKSYSGUARD_PROCESSCORE) << "Sending signal" << signal << "to" << pids;
 
-    auto result = d->applyToPids(pids, [signal](int pid) { return s_localProcesses->sendSignal(pid, signal); });
+    auto result = d->applyToPids(pids, [signal](int pid) {
+        return s_localProcesses->sendSignal(pid, signal);
+    });
     if (result.unchanged.isEmpty()) {
         return result.resultCode;
     }
 
-    return d->runKAuthAction(
-        QStringLiteral("org.kde.ksysguard.processlisthelper.sendsignal"),
-        result.unchanged,
-        { {QStringLiteral("signal"), signal} }
-    );
+    return d->runKAuthAction(QStringLiteral("org.kde.ksysguard.processlisthelper.sendsignal"), result.unchanged, {{QStringLiteral("signal"), signal}});
 }
 
-KSysGuard::ProcessController::Result KSysGuard::ProcessController::sendSignal(const QList<long long>& pids, int signal)
+KSysGuard::ProcessController::Result KSysGuard::ProcessController::sendSignal(const QList<long long> &pids, int signal)
 {
     return sendSignal(d->listToVector(pids), signal);
 }
@@ -100,21 +83,19 @@ KSysGuard::ProcessController::Result KSysGuard::ProcessController::sendSignal(co
     return sendSignal(d->listToVector(pids), signal);
 }
 
-ProcessController::Result ProcessController::setPriority(const QVector<int>& pids, int priority)
+ProcessController::Result ProcessController::setPriority(const QVector<int> &pids, int priority)
 {
-    auto result = d->applyToPids(pids, [priority](int pid) { return s_localProcesses->setNiceness(pid, priority); });
+    auto result = d->applyToPids(pids, [priority](int pid) {
+        return s_localProcesses->setNiceness(pid, priority);
+    });
     if (result.unchanged.isEmpty()) {
         return result.resultCode;
     }
 
-    return d->runKAuthAction(
-        QStringLiteral("org.kde.ksysguard.processlisthelper.renice"),
-        result.unchanged,
-        { { QStringLiteral("nicevalue"), priority } }
-    );
+    return d->runKAuthAction(QStringLiteral("org.kde.ksysguard.processlisthelper.renice"), result.unchanged, {{QStringLiteral("nicevalue"), priority}});
 }
 
-KSysGuard::ProcessController::Result KSysGuard::ProcessController::setPriority(const QList<long long>& pids, int priority)
+KSysGuard::ProcessController::Result KSysGuard::ProcessController::setPriority(const QList<long long> &pids, int priority)
 {
     return setPriority(d->listToVector(pids), priority);
 }
@@ -124,7 +105,7 @@ KSysGuard::ProcessController::Result KSysGuard::ProcessController::setPriority(c
     return setPriority(d->listToVector(pids), priority);
 }
 
-ProcessController::Result ProcessController::setCPUScheduler(const QVector<int>& pids, Process::Scheduler scheduler, int priority)
+ProcessController::Result ProcessController::setCPUScheduler(const QVector<int> &pids, Process::Scheduler scheduler, int priority)
 {
     if (scheduler == KSysGuard::Process::Other || scheduler == KSysGuard::Process::Batch) {
         priority = 0;
@@ -137,14 +118,12 @@ ProcessController::Result ProcessController::setCPUScheduler(const QVector<int>&
         return result.resultCode;
     }
 
-    return d->runKAuthAction(
-        QStringLiteral("org.kde.ksysguard.processlisthelper.changecpuscheduler"),
-        result.unchanged,
-        {{QStringLiteral("cpuScheduler"), scheduler}, {QStringLiteral("cpuSchedulerPriority"), priority}}
-    );
+    return d->runKAuthAction(QStringLiteral("org.kde.ksysguard.processlisthelper.changecpuscheduler"),
+                             result.unchanged, //
+                             {{QStringLiteral("cpuScheduler"), scheduler}, {QStringLiteral("cpuSchedulerPriority"), priority}});
 }
 
-KSysGuard::ProcessController::Result KSysGuard::ProcessController::setCPUScheduler(const QList<long long>& pids, Process::Scheduler scheduler, int priority)
+KSysGuard::ProcessController::Result KSysGuard::ProcessController::setCPUScheduler(const QList<long long> &pids, Process::Scheduler scheduler, int priority)
 {
     return setCPUScheduler(d->listToVector(pids), scheduler, priority);
 }
@@ -154,7 +133,7 @@ KSysGuard::ProcessController::Result KSysGuard::ProcessController::setCPUSchedul
     return setCPUScheduler(d->listToVector(pids), scheduler, priority);
 }
 
-ProcessController::Result ProcessController::setIOScheduler(const QVector<int>& pids, Process::IoPriorityClass priorityClass, int priority)
+ProcessController::Result ProcessController::setIOScheduler(const QVector<int> &pids, Process::IoPriorityClass priorityClass, int priority)
 {
     if (!s_localProcesses->supportsIoNiceness()) {
         return Result::Unsupported;
@@ -175,26 +154,26 @@ ProcessController::Result ProcessController::setIOScheduler(const QVector<int>&
         return result.resultCode;
     }
 
-    return d->runKAuthAction(
-        QStringLiteral("org.kde.ksysguard.processlisthelper.changeioscheduler"),
-        result.unchanged,
-        {{QStringLiteral("ioScheduler"), priorityClass}, {QStringLiteral("ioSchedulerPriority"), priority}}
-    );
+    return d->runKAuthAction(QStringLiteral("org.kde.ksysguard.processlisthelper.changeioscheduler"),
+                             result.unchanged, //
+                             {{QStringLiteral("ioScheduler"), priorityClass}, {QStringLiteral("ioSchedulerPriority"), priority}});
 }
 
-KSysGuard::ProcessController::Result KSysGuard::ProcessController::setIOScheduler(const QList<long long>& pids, Process::IoPriorityClass priorityClass, int priority)
+KSysGuard::ProcessController::Result
+KSysGuard::ProcessController::setIOScheduler(const QList<long long> &pids, Process::IoPriorityClass priorityClass, int priority)
 {
     return setIOScheduler(d->listToVector(pids), priorityClass, priority);
 }
 
-KSysGuard::ProcessController::Result KSysGuard::ProcessController::setIOScheduler(const QVariantList &pids, Process::IoPriorityClass priorityClass, int priority)
+KSysGuard::ProcessController::Result
+KSysGuard::ProcessController::setIOScheduler(const QVariantList &pids, Process::IoPriorityClass priorityClass, int priority)
 {
     return setIOScheduler(d->listToVector(pids), priorityClass, priority);
 }
 
 QString ProcessController::resultToString(Result result)
 {
-    switch(result) {
+    switch (result) {
     case Result::Success:
         return i18n("Success");
     case Result::InsufficientPermissions:
@@ -212,11 +191,10 @@ QString ProcessController::resultToString(Result result)
     }
 }
 
-ApplyResult KSysGuard::ProcessController::Private::applyToPids(const QVector<int>& pids, const std::function<Processes::Error(int)>& function)
+ApplyResult KSysGuard::ProcessController::Private::applyToPids(const QVector<int> &pids, const std::function<Processes::Error(int)> &function)
 {
     ApplyResult result;
 
-
     for (auto pid : pids) {
         auto error = function(pid);
         switch (error) {
@@ -240,8 +218,7 @@ ApplyResult KSysGuard::ProcessController::Private::applyToPids(const QVector<int
     return result;
 }
 
-
-ProcessController::Result ProcessController::Private::runKAuthAction(const QString& actionId, const QVector<int> &pids, const QVariantMap& options)
+ProcessController::Result ProcessController::Private::runKAuthAction(const QString &actionId, const QVector<int> &pids, const QVariantMap &options)
 {
     KAuth::Action action(actionId);
     if (!action.isValid()) {
@@ -262,7 +239,7 @@ ProcessController::Result ProcessController::Private::runKAuthAction(const QStri
     }
 
     KAuth::ExecuteJob *job = action.execute();
-    if(job->exec()) {
+    if (job->exec()) {
         return Result::Success;
     } else {
         if (job->error() == KAuth::ActionReply::UserCancelledError) {
@@ -279,16 +256,20 @@ ProcessController::Result ProcessController::Private::runKAuthAction(const QStri
     }
 }
 
-QVector<int> KSysGuard::ProcessController::Private::listToVector(const QList<long long>& list)
+QVector<int> KSysGuard::ProcessController::Private::listToVector(const QList<long long> &list)
 {
     QVector<int> vector;
-    std::transform(list.cbegin(), list.cend(), std::back_inserter(vector), [](long long entry) { return entry; });
+    std::transform(list.cbegin(), list.cend(), std::back_inserter(vector), [](long long entry) {
+        return entry;
+    });
     return vector;
 }
 
 QVector<int> KSysGuard::ProcessController::Private::listToVector(const QVariantList &list)
 {
     QVector<int> vector;
-    std::transform(list.cbegin(), list.cend(), std::back_inserter(vector), [](const QVariant &entry) { return entry.toInt(); });
+    std::transform(list.cbegin(), list.cend(), std::back_inserter(vector), [](const QVariant &entry) {
+        return entry.toInt();
+    });
     return vector;
 }
