@@ -1,24 +1,11 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2009 Pino Toscano <pino@kde.org>
+/*
+    SPDX-FileCopyrightText: 2009 Pino Toscano <pino@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "processes_local_p.h"
 #include "process.h"
+#include "processes_local_p.h"
 
 #ifdef __GNUC__
 #warning Totally bogus ProcessesLocal implementation
@@ -26,17 +13,17 @@
 
 namespace KSysGuard
 {
-
 class ProcessesLocal::Private
 {
 public:
     Private()
-    {}
+    {
+    }
     ~Private()
-    {}
+    {
+    }
 };
 
-
 ProcessesLocal::ProcessesLocal()
     : d(0)
 {
@@ -44,7 +31,7 @@ ProcessesLocal::ProcessesLocal()
 
 ProcessesLocal::~ProcessesLocal()
 {
-   delete d;
+    delete d;
 }
 
 long ProcessesLocal::getParentPid(long pid)
@@ -79,7 +66,6 @@ Processes::Error ProcessesLocal::setScheduler(long pid, int priorityClass, int p
     return Processes::NotSupported;
 }
 
-
 Processes::Error ProcessesLocal::setIoNiceness(long pid, int priorityClass, int priority)
 {
     return Processes::NotSupported;
