@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2019 Eike Hein <hein@kde.org>
-    Copyright (C) 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
+    SPDX-FileCopyrightText: 2019 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2020 Arjen Hiemstra <ahiemstra@heimr.nl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "SensorTreeModel.h"
@@ -31,13 +18,12 @@
 
 #include "Sensor.h"
 #include "SensorDaemonInterface_p.h"
-#include "SensorQuery.h"
 #include "SensorGroup_p.h"
+#include "SensorQuery.h"
 
 using namespace KSysGuard;
 
-struct Q_DECL_HIDDEN SensorTreeItem
-{
+struct Q_DECL_HIDDEN SensorTreeItem {
     SensorTreeItem *parent = nullptr;
     QString segment;
     QMap<QString, SensorTreeItem *> children;
@@ -55,7 +41,8 @@ struct Q_DECL_HIDDEN SensorTreeItem
         return -1;
     }
 
-    inline SensorTreeItem *itemAt(int index) {
+    inline SensorTreeItem *itemAt(int index)
+    {
         int currentIndex = 0;
         for (auto child : qAsConst(children)) {
             if (currentIndex++ == index) {
@@ -121,7 +108,7 @@ void SensorTreeModel::Private::addSensor(const QString &sensorId, const SensorIn
         } else {
             m_groupMatches[sensorIdExpr] = 1;
         }
-        
+
         if (m_groupMatches[sensorIdExpr] == 2) {
             SensorInfo newInfo;
             newInfo.name = m_sensorGroup->sensorNameForRegEx(sensorIdExpr);
@@ -130,7 +117,7 @@ void SensorTreeModel::Private::addSensor(const QString &sensorId, const SensorIn
             newInfo.unit = info.unit;
             newInfo.min = info.min;
             newInfo.max = info.max;
-            
+
             addSensor(sensorIdExpr, newInfo);
         }
     }
@@ -304,7 +291,7 @@ QVariant SensorTreeModel::data(const QModelIndex &index, int role) const
         }
 
         return d->m_sensorGroup->segmentNameForRegEx(item->segment);
-    // Only leaf nodes are valid sensors
+        // Only leaf nodes are valid sensors
     } else if (role == SensorId) {
         if (rowCount(index)) {
             return QString();
