@@ -1,22 +1,8 @@
 /*
- * Copyright 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2019 Arjen Hiemstra <ahiemstra@heimr.nl>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "AggregateSensor.h"
 
@@ -35,7 +21,7 @@ using namespace KSysGuard;
 // returned.
 QVariant addVariants(const QVariant &first, const QVariant &second)
 {
-    auto result = QVariant {};
+    auto result = QVariant{};
 
     bool convertFirst = false;
     bool convertSecond = false;
@@ -89,7 +75,12 @@ public:
 };
 
 AggregateSensor::AggregateSensor(SensorObject *provider, const QString &id, const QString &name)
-    : SensorProperty(id, name, provider)
+    : AggregateSensor(provider, id, name, QVariant{})
+{
+}
+
+AggregateSensor::AggregateSensor(SensorObject *provider, const QString &id, const QString &name, const QVariant &initialValue)
+    : SensorProperty(id, name, initialValue, provider)
     , d(std::make_unique<Private>())
 {
     d->subsystem = qobject_cast<SensorContainer *>(provider->parent());
@@ -217,14 +208,13 @@ void AggregateSensor::updateSensors()
     while (itr != d->sensors.end()) {
         if (!itr.value()) {
             itr = d->sensors.erase(itr);
-        } else if (itr.value()->parent() && itr.value()->parent()->parent() != d->subsystem){
+        } else if (itr.value()->parent() && itr.value()->parent()->parent() != d->subsystem) {
             itr.value()->disconnect(this);
             if (isSubscribed()) {
                 itr.value()->unsubscribe();
             }
             itr = d->sensors.erase(itr);
-        }
-        else {
+        } else {
             ++itr;
         }
     }
@@ -238,7 +228,6 @@ void AggregateSensor::updateSensors()
         }
     }
 
-
     delayedEmitDataChanged();
 }
 
